@@ -37,6 +37,9 @@ class SQLServer(Abstract_DB):
 
         conn_str = s.get("CONN_STR", "")
 
+        credentials_kargs = {}
+        if s.get("USER", None):
+            credentials_kargs = {"user": s.user, "password": s.password}
         try:
             connection = pyodbc.connect(
                 conn_str,
@@ -44,8 +47,7 @@ class SQLServer(Abstract_DB):
                 server=s.ip,
                 port=s.get("PORT", None),
                 database=s.base,
-                user=s.get("USER", None),
-                password=s.get("PASSWORD", None),
+                **credentials_kargs,
             )
         except BaseException as e:
             logger.error(f"Can't set up a connection with {s.ip}/{s.base}, {e}")
