@@ -10,6 +10,7 @@ logger = logging.getLogger(__name__)
 
 
 def make_dir(path):
+    path = path.rsplit("/", 1)[0]
     Path(path).mkdir(parents=True, exist_ok=True)
 
 
@@ -20,7 +21,7 @@ class LocalSaveHandler(AbstractSaveHandler):
         self.dir = "data/" + self.dir
 
     def write_file(self, dirname, filename, obj):
-        make_dir(dirname)
+        make_dir(dirname + filename)
         mode = "w" if isinstance(obj, str) else "wb"
         with open(dirname + filename, mode) as f:
             f.write(obj)
